/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	AnimControl
**
** DESCRIPTION:	Control the current animation of a villager
**
**
\******************************************************************************/

#ifndef ANIM_CONTROL_H
#define ANIM_CONTROL_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "AnimManager.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CAnimControl
{
public:
	//setup
	CAnimControl(void);
	void Reset();

	//process

	void Update(EAnimFrame &eAnimFrame, EHeadDirection &eHeadDirection, EDirection &eDirection);
	void Play(const char *animName, const bool bIsReversed = false, const float fSpeed = 0.0f);
	void Play(const EAnim eAnim, const bool bIsReversed = false, const float fSpeed = 0.0f);
	void Stop();

	//access

	void   SetSpeed(const float fSpeed);
	void   SetMaxSpeed(float maxSpeed) {m_fMaxSpeed = maxSpeed;}
	EAnim  GetCurrentAnim() {return m_eAnim;}
	int    GetAnimTicks()   {return (int) m_fTime;}

private:

	//class data
	EAnim			m_eAnim;
	float			m_fTime;
	float			m_fSpeed;
	float			m_fMaxSpeed;
	bool			m_bIsReversed;
	int				m_iPrevTime;
	bool			m_bFirstFrame;
};

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/