/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	Bath 
**
** DESCRIPTION:	Bath Restoration Puzzle
**
**      AUTHOR:	Arthur Humphrey, from template of Adrian Francis
**
\******************************************************************************/

#ifndef CHILDRENSTOTEMPUZZLE_H
#define CHILDRENSTOTEMPUZZLE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "../Game/theGameState.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

//const ldwPoint Fruitwells_c_sCenter(114, 1802);

enum EChildrensTotemStatus
{
	eChildrensTotem_InitialState = 0,
	eChildrensTotem_WorkStarted,
	eChildrensTotem_OneQuarterDown,
	eChildrensTotem_OneHalfDown,
	eChildrensTotem_ThreeQuartersDown,
	eChildrensTotem_Down,
	eChildrensTotem_NumberOfStates

};

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CChildrensTotemPuzzle : public IPuzzle
{
	friend class CPuzzle;

public:

	CChildrensTotemPuzzle(void);



	EChildrensTotemStatus m_eChildrensTotemStatus;

	void Reset();

	const int	LoadState(const unsigned char *pData);
	const int	SaveState(const unsigned char *pData, const int iMaxDataSize) const;
	bool		AdvancePuzzleState();
	EChildrensTotemStatus	 GetStatus();
	int GetPercentComplete();

	void AdjustNumKids(int adjustment);
	void Draw() const;
	

	void		Draw(const int iRef);
	const int SaveStateSize() {return sizeof (SSaveState);}
	void		LoadAssets();
	void		ReleaseAssets();

	// process
	void Refresh();
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Advance(int howMany);
	void Complete();

	// access

private:
	

	//class structures
	struct SSaveState
	{
		EChildrensTotemStatus	m_eChildrensTotemStatus;
		int					m_iChildrensTotemProgress;
	};
	
	int m_iChildrensTotemProgress;
	int m_iHowManyChildrenInTotem;
	
	//class data
	
	theGameState  *gs;

	ldwImageGrid *	m_pScaffold;
	
	ldwUINT32 	m_u5thChildTimer;
	
	ldwImageGrid *	m_pTotem;

	ldwImageGrid *	m_pBlinkyEyes;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CChildrensTotemPuzzle		ChildrensTotemPuzzle;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/