/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	CollectableItem
**
** DESCRIPTION:	Manages collectable items which are collected by the player
**
**
\******************************************************************************/

#ifndef COLLECTABLE_ITEM_H
#define COLLECTABLE_ITEM_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "CollectableInterface.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/
const int CollectableItem_c_iMaxCollectables = 62;
const int CollectableItem_c_iMaxSpawnAreas   = 8;

const int CollectableItem_c_iMaxRandomCollectables = 2;

const int CollectableItem_c_iTimeOut = 90;

const int CollectableItem_c_iChanceOfCollectable = 3; 
const int CollectableItem_c_iChanceOfUncommonCollectable = 18;
const int CollectableItem_c_iChanceOfRareCollectable = 5;

const int CollectableItem_c_iChanceOfShroom = 30;
const int CollectableItem_c_iChanceOfRareShroom = 8;

const int CollectableItem_c_iCommonCollectableTechValue = 100;
const int CollectableItem_c_iUncommonCollectableTechValue = 250;
const int CollectableItem_c_iRareCollectableTechValue = 1500;

const int CollectableItem_c_iCommonCollectableManaValue = 10;
const int CollectableItem_c_iUncommonCollectableManaValue = 50;
const int CollectableItem_c_iRareCollectableManaValue = 150;

const int CollectableItem_c_iNumCollections = eCarrying_NumberOf - eCarrying_BeginCollectables;

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CCollectableItem : public ICollectable
{
private:

	struct SCollectable
	{
		bool			m_bExists;
		ECarrying		m_eType;
		unsigned int	m_uiTimeout;
		ldwPoint		m_sPos;

		int				m_iCollector;
		unsigned int	m_uiCollectionTime;
	};

	struct SSpawnArea
	{
		ldwRect			m_sRect;
		ECarrying		m_eType;
	};
public:

	//class structures
	struct SSaveState
	{
		int				m_iCollectionCount[CollectableItem_c_iNumCollections];

		SSpawnArea		m_sSpawnArea[CollectableItem_c_iMaxSpawnAreas];
		int				m_iNumSpawnAreas;
	};

	CCollectableItem(void);

	void Reset();
	void LoadAssets();
	void ReleaseAssets();

	const bool LoadState(const SSaveState &sSaveState);
	const bool SaveState(SSaveState &sSaveState) const;

	void AddSpawnArea(const ldwRect sRect, const ECarrying eType);
	void Add(const ECarrying eCarrying = eCarrying_Nothing, const ldwPoint sPos = ldwPoint(0, 0), const bool bIncludeCommon = true, const bool bIncludeUncommon = true, const bool bIncludeRare = true, const bool bIncludeShrooms = true);
	void AddRare(bool spawnGhost = false);
	void AddTutorialItem();

	void Remove(const int iCollectable);
	void Update();
	void Draw();
	void Draw(const int iCollectable);

	const bool Carry(CVillager &Villager, const ECarrying eCarrying);
	void       Drop(CVillager &Villager, const ECarrying eCarrying);

	const ECarrying GetNearbyCollectable(CVillager &Villager, const ldwPoint sPos);
	const bool      IsCommonCollectable(const ECarrying eCarrying) const;
	const bool      IsUncommonCollectable(const ECarrying eCarrying) const;
	const bool      IsRareCollectable(const ECarrying eCarrying) const;
	const bool      IsCollectionComplete(const ECarrying eCarrying) const;
	const int       CollectionCount(const ECarrying eCarrying, const bool bIncludeCommon = true, const bool bIncludeUncommon = true, const bool bIncludeRare = true) const;
	const int       Count(const ECarrying eCarrying) const;
	const bool      WasItemSpawned(const ECarrying eCarrying) const;
	const bool      IsItemBeingCarried(const ECarrying eCarrying) const;
	const bool      WasItemAlreadyCollected(const ECarrying eCarrying) const;

private:

	int GetAvailableSlot(bool notRandom);

	//class data
	SCollectable		m_sCollectable[CollectableItem_c_iMaxCollectables];
	SSpawnArea			m_sSpawnArea[CollectableItem_c_iMaxSpawnAreas];
	int					m_iNumSpawnAreas;

	int					m_iCollectionCount[CollectableItem_c_iNumCollections];
	int					m_iNearestCollectable;
	ldwImageGrid *		m_pCollectables;
};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CCollectableItem		CollectableItem;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/