/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	Bath 
**
** DESCRIPTION:	Bath Restoration Puzzle
**
**      AUTHOR:	Arthur Humphrey, from template of Adrian Francis
**
\******************************************************************************/

#ifndef ConvertMasterScientistPUZZLE_H
#define ConvertMasterScientistPUZZLE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "../Game/theGameState.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

//const ldwPoint Fruitwells_c_sCenter(114, 1802);

enum EConvertMasterScientistStatus
{
	eConvertMasterScientist_InitialState = 0,
	eConvertMasterScientist_WorkStarted,
	eConvertMasterScientist_OneQuarterDown,
	eConvertMasterScientist_OneHalfDown,
	eConvertMasterScientist_ThreeQuartersDown,
	eConvertMasterScientist_Down,
	eConvertMasterScientist_NumberOfStates

};

enum EProofQuality
{
	eProof_Clever,
	eProof_Crappy
};
/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CConvertMasterScientistPuzzle : public IPuzzle
{
	friend class CPuzzle;

public:

	CConvertMasterScientistPuzzle(void);



	EConvertMasterScientistStatus m_eConvertMasterScientistStatus;

	void Reset();

	const int	LoadState(const unsigned char *pData);
	const int	SaveState(const unsigned char *pData, const int iMaxDataSize) const;
	bool		AdvancePuzzleState();
	EConvertMasterScientistStatus	 GetStatus();
	int GetPercentComplete();

	void AdjustNumKids(int adjustment);
	void Draw() const;
	void		Draw(const int iRef);

	//void		Draw(const int iRef);
	const int SaveStateSize() {return sizeof (SSaveState);}
	void		LoadAssets();
	void		ReleaseAssets();

	// process
	void Refresh();
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Advance(int howMany);
	void Complete();

	// access

private:
	

	//class structures
	struct SSaveState
	{
		EConvertMasterScientistStatus	m_eConvertMasterScientistStatus;
		int					m_iConvertMasterScientistProgress;
	};
	
	int m_iConvertMasterScientistProgress;
	int m_iHowManyChildrenInTotem;
	
	//class data
	EProofQuality m_eProofQuality;
	theGameState  *gs;

	ldwImageGrid *	m_pScaffold;
	
	ldwUINT32 	m_u5thChildTimer;
	
	ldwImageGrid *	m_pTotem;

	ldwImageGrid *	m_pBlinkyEyes;

	ldwImageGrid *  m_pNecklacePiece;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CConvertMasterScientistPuzzle		ConvertMasterScientistPuzzle;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/