/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	FirePit
**
** DESCRIPTION:	Fire pit puzzle
**
\******************************************************************************/

#ifndef FIREPIT_H
#define FIREPIT_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "Puzzle.h"
#include "../Collectables/CollectableInterface.h"
#include "../Game/GameTimer.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/
const int FirePit_c_iBurnTime            = 20 * 60 * 60;

#if _DEBUG
const int FirePit_c_iWaterNeedForCooling   = 4;
const int FirePit_c_iWaterNeededForFireOut = 2;
#else
const int FirePit_c_iWaterNeedForCooling   = 12;
const int FirePit_c_iWaterNeededForFireOut = 4;
#endif
const int FirePit_c_iTimeToCompleteCooling = 10 * 60;

const ldwPoint FirePit_c_sCenter(1307, 1220);

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CFirePit : public IPuzzle, public ICollectable
{
	friend class CPuzzle;

public:

	enum
	{
		eNeedFire
	};

	CFirePit(void);

	void Reset();

	void ResetFire();

	void LoadAssets();
	void ReleaseAssets();

	const int LoadState(const unsigned char *pData);
	const int SaveState(const unsigned char *pData, const int iMaxDataSize) const;

	const int SaveStateSize() {return sizeof (SSaveState);}

	// process

	void Refresh();
	void Draw() const;
	void Draw(const int iRef);
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void CheckAdvance(CVillager &villager,int checkWhat);
	void Complete();

	const bool Carry(CVillager &Villager, const ECarrying eCarrying);
	void Drop(CVillager &Villager, const ECarrying eCarrying);

	void LightFire();
	void ExtinguishFire();
	void Poof();
	void BlackPoof();

	// access

	const ECarrying GetNearbyCollectable(CVillager &Villager, const ldwPoint sPos);
	const bool ContainsKindling() const { return m_bContainsKindling; }
	const bool ContainsFirewood() const { return m_bContainsFirewood; }
	const bool IsLit() const;
	const int SecondsRemainingOnFire() const;
	const int TotalBurnTime() const;
	const bool IsCooling() const;
	const bool HasCooled() const;

private:

	//class structures
	struct SSaveState
	{
		bool			m_bContainsKindling;
		bool			m_bContainsFirewood;
		ldwUINT32		m_uiBurnOutTime;
		ldwUINT32    	m_uiFireCooledTime;
		ldwUINT32		m_iTotalBurnTime;
		ldwUINT32		m_prevBurnTimeRemaining;
	};

	//class data
	bool			m_bContainsKindling;
	bool			m_bContainsFirewood;
	CGameTimer		m_BurnOutTimer;
	CGameTimer      m_FireCooledTimer;
	ldwUINT32		m_iTotalBurnTime;
	ldwUINT32		m_prevBurnTimeRemaining;

	int				m_iSmoke;

	ldwImageGrid *	m_pFirewood;
	ldwImageGrid *	m_pKindling;
};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CFirePit		FirePit;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/