/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	Bath 
**
** DESCRIPTION:	Bath Restoration Puzzle
**
**      AUTHOR:	Arthur Humphrey, from template of Adrian Francis
**
\******************************************************************************/

#ifndef FOODTOTEMPUZZLE_H
#define FOODTOTEMPUZZLE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "../Game/theGameState.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

//const ldwPoint Fruitwells_c_sCenter(114, 1802);

enum EFoodTotemStatus
{
	eFoodTotem_InitialState = 0,
	eFoodTotem_WorkStarted,
	eFoodTotem_OneQuarterDown,
	eFoodTotem_OneHalfDown,
	eFoodTotem_ThreeQuartersDown,
	eFoodTotem_Down,
	eFoodTotem_NumberOfStates

};

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CFoodTotemPuzzle : public IPuzzle
{
	friend class CPuzzle;

public:

	CFoodTotemPuzzle(void);



	EFoodTotemStatus m_eFoodTotemStatus;

	void Reset();

	const int	LoadState(const unsigned char *pData);
	const int	SaveState(const unsigned char *pData, const int iMaxDataSize) const;
	bool		AdvancePuzzleState();
	EFoodTotemStatus	 GetStatus();
	int GetPercentComplete();

	void Draw() const;
	

	void		Draw(const int iRef);
	const int SaveStateSize() {return sizeof (SSaveState);}
	void		LoadAssets();
	void		ReleaseAssets();

	// process
	void Refresh();
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Advance(EFoodTotemStatus currentStatus);
	void Complete();

	// access

private:
	

	//class structures
	struct SSaveState
	{
		EFoodTotemStatus	m_eFoodTotemStatus;
		int					m_iFoodTotemProgress;
	};
	
	int m_iFoodTotemProgress;
	
	//class data
	
	theGameState  *gs;

	ldwImageGrid *	m_pScaffold;

	ldwImageGrid *	m_pTotem;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CFoodTotemPuzzle		FoodTotemPuzzle;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/