/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	HydroFarm
**
** DESCRIPTION:	Hydro farm puzzle
**
\******************************************************************************/

#ifndef HYDROFARM_H
#define HYDROFARM_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "Puzzle.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/
#ifdef _DEBUG
const int HydroFarm_c_iIterationsToRepairAqueduct = 4;
#else
const int HydroFarm_c_iIterationsToRepairAqueduct = 30;
#endif

const ldwPoint HydroFarm_c_sSunbeamPos = ldwPoint(1070, 520);

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CHydroFarm : public IPuzzle
{
	friend class CPuzzle;

public:

	CHydroFarm(void);

	void Reset();

	void LoadAssets();
	void ReleaseAssets();

	const int LoadState(const unsigned char *pData);
	const int SaveState(const unsigned char *pData, const int iMaxDataSize) const;

	const int SaveStateSize() {return sizeof (SSaveState);}

	// process

	void Draw() const;
	void Draw(const int iRef);
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Complete();

	void RefreshCrops(void);
	void InflictEarthQuakeDamage(void);

	// access
	const bool IsAqueductRepaired(void);
	const int PercentComplete(void);

private:

	//class structures
	struct SSaveState
	{
		int			m_iDummyData;	// Compiler assumes 1 byte if this struct is empty and screws up the save system
	};

	//class data
	ldwImageGrid *	m_pAqueduct[3];
	ldwImageGrid *  m_pNecklacePiece;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CHydroFarm		HydroFarm;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/