/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	Bath 
**
** DESCRIPTION:	Bath Restoration Puzzle
**
**      AUTHOR:	Arthur Humphrey, from template of Adrian Francis
**
\******************************************************************************/

#ifndef MEDICINETOTEMPUZZLE_H
#define MEDICINETOTEMPUZZLE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "../Game/theGameState.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

//const ldwPoint Fruitwells_c_sCenter(114, 1802);

enum EMedicineTotemStatus
{
	eMedicineTotem_InitialState = 0,
	eMedicineTotem_WorkStarted,
	eMedicineTotem_OneQuarterDown,
	eMedicineTotem_OneHalfDown,
	eMedicineTotem_ThreeQuartersDown,
	eMedicineTotem_TotemDown,
	eMedicineTotem_NumberOfStates

};

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CMedicineTotemPuzzle : public IPuzzle
{
	friend class CPuzzle;

public:

	CMedicineTotemPuzzle(void);



	EMedicineTotemStatus m_eMedicineTotemStatus;

	void Reset();

	const int	LoadState(const unsigned char *pData);
	const int	SaveState(const unsigned char *pData, const int iMaxDataSize) const;
	bool		AdvancePuzzleState();
	EMedicineTotemStatus	 GetStatus();
	int GetPercentComplete();
	bool GetElectricityOn();
	void StartElectricityTimer();

	void Draw() const;
	

	void		Draw(const int iRef);
	const int SaveStateSize() {return sizeof (SSaveState);}
	void		LoadAssets();
	void		ReleaseAssets();

	// process
	void Refresh();
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Advance(EMedicineTotemStatus currentStatus);
	void Complete();

	void Zap(CVillager *pVillager);

	// access

private:
	

	//class structures
	struct SSaveState
	{
		EMedicineTotemStatus	m_eMedicineTotemStatus;
		int					m_iMedicineTotemProgress;
	};
	
	int m_iMedicineTotemProgress;

	ldwUINT32 m_uPlantTimer;
	ldwUINT32 m_uElectricityTimer;
	int	m_iLightningEffect;
	//class data
	
	theGameState  *gs;

	ldwImageGrid *	m_pScaffold;

	ldwImageGrid *	m_pTotem;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CMedicineTotemPuzzle		MedicineTotemPuzzle;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/