/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	PuzzleInterface
**
** DESCRIPTION:	Interface for puzzle modules
**
**      AUTHOR:	Adrian Francis
**
\******************************************************************************/

#ifndef PUZZLE_INTERFACE_H
#define PUZZLE_INTERFACE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
class CVillager;

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class IPuzzle
{
public:
	//interface methods
	//setup
	virtual void Reset() = 0;

	virtual void LoadAssets() {};
	virtual void ReleaseAssets() {};

	virtual const int LoadState(const unsigned char *pData) = 0;
	virtual const int SaveState(const unsigned char *pData, const int iMaxDataSize) const = 0;

	virtual const int SaveStateSize() = 0;

	// process
	virtual void Refresh() {};
	virtual void Draw() const {};
	virtual void Draw(const int iRef) {};
	virtual void Update() {};
	virtual void Advance(CVillager &Villager, const int iRef = -1) {};
	virtual void Complete() {};
	virtual void CheckAdvance(CVillager &villager,int checkWhat) {}

	// access
	virtual	int InitialPoints() {return 0;}
	virtual const int PercentComplete(void) { return -1; }
};

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/