/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	Bath 
**
** DESCRIPTION:	Bath Restoration Puzzle
**
**      AUTHOR:	Arthur Humphrey, from template of Adrian Francis
**
\******************************************************************************/

#ifndef RainbowTOTEMPUZZLE_H
#define RainbowTOTEMPUZZLE_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwImage.h"
#include "PuzzleInterface.h"
#include "../Game/theGameState.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/

//const ldwPoint Fruitwells_c_sCenter(114, 1802);

enum ERainbowTotemStatus
{
	eRainbowTotem_InitialState = 0,
	eRainbowTotem_WorkStarted,
	eRainbowTotem_OneQuarterDown,
	eRainbowTotem_OneHalfDown,
	eRainbowTotem_ThreeQuartersDown,
	eRainbowTotem_Down,
	eRainbowTotem_NumberOfStates

};



enum EDyeColor
{
	eDyeColor_None = 0,
	eDyeColor_Red,
	eDyeColor_Blue,
	eDyeColor_Yellow,
	eDyeColor_Purple,
	eDyeColor_Green,
	eDyeColor_Orange,
	eDyeColor_Brown,

};
/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CRainbowTotemPuzzle : public IPuzzle
{
	friend class CPuzzle;

public:

	CRainbowTotemPuzzle(void);



	ERainbowTotemStatus m_eRainbowTotemStatus;

	void Reset();

	const int	LoadState(const unsigned char *pData);
	const int	SaveState(const unsigned char *pData, const int iMaxDataSize) const;
	bool		AdvancePuzzleState();
	ERainbowTotemStatus	 GetStatus();
	int GetPercentComplete();

	void Draw() const;
	

	void		Draw(const int iRef);
	const int SaveStateSize() {return sizeof (SSaveState);}
	void		LoadAssets();
	void		ReleaseAssets();

	// process
	void Refresh();
	void Update();
	void Advance(CVillager &Villager, const int iRef);
	void Advance(ERainbowTotemStatus currentStatus);
	void Complete();
	void DyeTimerHandler(EDyeColor color);
	bool GetDyeIsActive(EDyeColor color);
	EDyeColor GetCurrentWaterColor();
	// access

private:
	
	ldwUINT32 redDyeTimer;
	ldwUINT32 blueDyeTimer;

	ldwUINT32 yellowDyeTimer;
	ldwUINT32 MasterDyeTimer;
	float	  masterDyeAlpha;
	bool	  masterFadeIn;
	bool	  masterFadeOut;
	bool	  newColorAdded;

	float	  dyeAlphaRed;
	float	  dyeAlphaBlue;
	float	  dyeAlphaYellow;
	float	  dyeAlphaPurple;
	float	  dyeAlphaGreen;
	float	  dyeAlphaOrange;
	float	  dyeAlphaBrown;
	bool	  dyeFadingInRed;
	bool	  dyeFadingOutRed;
	bool	  dyeFadingInBlue;
	bool	  dyeFadingOutBlue;	
	bool	  dyeFadingInYellow;
	bool	  dyeFadingOutYellow;
	bool	  dyeFadingInPurple;
	bool	  dyeFadingOutPurple;
	bool	  dyeFadingInGreen;
	bool	  dyeFadingOutGreen;
	bool	  dyeFadingInOrange;
	bool	  dyeFadingOutOrange;
	bool	  dyeFadingInBrown;
	bool	  dyeFadingOutBrown;
	//class structures
	struct SSaveState
	{
		ERainbowTotemStatus	m_eRainbowTotemStatus;
		int					m_iRainbowTotemProgress;
	};
	
	int m_iRainbowTotemProgress;

	EDyeColor m_eCurrentWaterColor;
	EDyeColor m_eNewDyeColor;
	EDyeColor m_eOldWaterColor;

	//class data
	
	theGameState  *gs;

	ldwImageGrid *	m_pScaffold;

	ldwImageGrid *	m_pTotem;

	ldwImageGrid *	m_pTopPoolOverlayRed;
	ldwImageGrid *	m_pTopPoolOverlayBlue;
	ldwImageGrid *	m_pTopPoolOverlayYellow;
	ldwImageGrid *	m_pTopPoolOverlayPurple;
	ldwImageGrid *	m_pTopPoolOverlayGreen;
	ldwImageGrid *	m_pTopPoolOverlayOrange;
	ldwImageGrid *	m_pTopPoolOverlayBrown;


	bool redDyeActive;
	bool blueDyeActive;
	bool yellowDyeActive;

};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CRainbowTotemPuzzle		RainbowTotemPuzzle;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/