/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	SunBeam
**
** DESCRIPTION:	Sun beam effect
**
\******************************************************************************/

#ifndef SUNBEAM_H
#define SUNBEAM_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwTypes.h"
#include "ldwImage.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/
const int SunBeam_c_iMaxSunBeams   = 48;
const int SunBeam_c_iMaxSpotlights = 16;

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CSunBeam
{
public:

	CSunBeam();
	~CSunBeam();

	void Reset(bool sunbeamsActive = false);
	void LoadAssets();
	void ReleaseAssets();

	void Update(bool sunbeamsActive = false);
	void Draw(bool sunbeamsActive = false);

	void AddSpotlight(ldwPoint where, float intensity, ldwUINT32 duration = 3, const bool bFadeOn = false);

private:

	struct SSunBeam
	{
		ldwPoint		m_sPos;
		float			m_fAlpha;
		unsigned int	m_uiFadeOffTime;
		bool			m_bIsFadingOn;
	};

	//class data
	SSunBeam		m_SunBeam[SunBeam_c_iMaxSunBeams];
	SSunBeam		m_Spotlight[SunBeam_c_iMaxSpotlights];

	int				m_SpotlightCount;

	ldwImage *		m_pSunBeamImage;
};

/******************************************************************************\
** GLOBAL DECLARATIONS
\******************************************************************************/
extern CSunBeam		SunBeam;

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/