/******************************************************************************\
**
**     COMPANY:	LDW Software
**
**      MODULE:	WorldPath
**
** DESCRIPTION:	Path of points for world navigation
**
**      AUTHOR:	Greg Hospelhorn
**
\******************************************************************************/

#ifndef WORLD_PATH_H
#define WORLD_PATH_H

/******************************************************************************\
** LIBRARY INCLUDES
\******************************************************************************/
#include "ldwTypes.h"
#include "ContentMap.h"

/******************************************************************************\
** CONSTANT DEFINITIONS
\******************************************************************************/
const int WorldPath_c_iMaxPathLength = 500;
const int WorldPath_c_iPathGradientNull      = 0x7fff;
const int WorldPath_c_iPathGradientMax       = WorldPath_c_iPathGradientNull - 1;
const int WorldPath_c_iPathGradientMin       = 1;
const int WorldPath_c_iPathGradientCellCount = ContentMap_c_iWidthInBlocks * ContentMap_c_iHeightInBlocks;
const int WorldPath_c_iPathGradientNoTarget  = -1;

/******************************************************************************\
** CLASS DEFINITIONS
\******************************************************************************/
class CWorldPath
{
#if _DEBUG
	friend class CWaypointEditor;
#endif

public:
	
	CWorldPath();

	bool FindPath(ldwPoint currentLocation,ldwPoint destination,ETerritory territory = eTerritory_Any, bool canSwim = false);

	void TruncatePath(int maxLength);

	ldwPoint NextPoint();
	bool	 Completed();

	void	SetLooseness(int looseness) {mLoosenessPercent = looseness;}
	int     GetLooseness() {return mLoosenessPercent;}


#if _DEBUG
	void    SavePathGradient() {mSavedPathGradient = mPathGradient;}
	void	DrawGradient();
#endif

private:

	//class structures
	struct PathGradient
	{
		ldwPoint destination;
#if _DEBUG
		int pathLength;
#endif	
		ldwUINT16 cell[WorldPath_c_iPathGradientCellCount];		
	};

	//class data
	ldwPoint mPoints[WorldPath_c_iMaxPathLength];

	int mLoosenessPercent;

	int mLength;
	int mCurrentIndex;

	bool       mDeepWaterOK;
	ETerritory mTerritory;

	static PathGradient mPathGradient;

#if _DEBUG
	static PathGradient mSavedPathGradient;
#endif


	bool	 CreatePath(CWorldPath &path,ldwPoint currentLocation,ldwPoint destination,ETerritory territory,bool deepWaterOK);


	bool     CreatePathGradient(PathGradient &gradient,ldwPoint destination,ldwPoint currentLocation,ETerritory territory,bool deepWaterOK);
	bool     OnPathGradientTarget(PathGradient &gradient,ldwPoint currentLocation);
	ldwPoint GetNextPointFromPathGradient(PathGradient &gradient,ldwPoint currentLocation,bool isRetry = false);

	bool 	 PathIsBlocked(int column,int row,ETerritory territory,bool deepWaterOK);
};

#endif

/******************************************************************************\
** END OF FILE
\******************************************************************************/
